#include <stdint.h>
#include "nano1xx.h"
/*
 *               A
 *         ----------
 *         |\   |J  /|
 *        F| H  |  K |B
 *         |  \ | /  |
 *         --G-- --M--
 *         |   /| \  |
 *       E |  Q |  N |C
 *         | /  |P  \|
 *         -----------
 *             D
*/
#define  a       0x01 
#define  b       0x02 
#define  c       0x04 
#define  d       0x08 
#define  e       0x10     
#define  f       0x20     
#define  g       0xC0     


const uint8_t Tab_Num[16]={
        a + b + c + d + e + f ,       //0
        b + c ,                       //1
        a + b + d + e + g ,           //2
        a + b + c + d + g ,           //3
        b + c + f + g ,               //4
        a + c + d + f + g ,           //5
        a + c + d + e + f + g ,       //6
        a + b + c ,                   //7
        a + b + c + d + e + f + g ,   //8
        a + b + c + d + f + g ,       //9
        d + e + f ,                   //A : L
        c + d + e + g ,               //B : o
        g ,                           //C : -
        e + g ,                       //D : r
        a + d + e + f + g ,           //E : E
        0 ,                           //F : 
} ;


const char NumComSegTab[7][14][2] = {
    {
        // 1
        //{com, seg}
        // A       // B       // C       // D
        {3,  0}, {2,  0}, {1,  0}, {0,  0},
        // E       // F       // G       // M
        {1, 32}, {2, 32}, {2, 33}, {1, 1},
        // J       // K       // H       // N
        {3,  1}, {2,  1}, {3,  33}, {0,  1},
        // P       // Q
        {0, 33}, {1, 33},
    },
    {
        // 2
        //{com, seg}
        // A       // B       // C       // D
        {3,  4}, {2,  4}, {1,  4}, {0,  4},
        // E       // F       // G       // M
        {1,  2}, {2,  2}, {2,  3}, {1,  5},
        // J       // K       // H       // N
        {3,  5}, {2,  5}, {3,  3}, {0, 5},
        // P       // Q
        {0,  3}, {1,  3},
    },
    {
        // 3
        //{com, seg}
        // A          // B     // C     // D
        {3,  8}, {2,  8}, {1,  8}, {0,   8},
        // E          // F       // G       // M
        {1,  6}, {2,  6}, {2,  7}, {1,   9},
        // J          // K       // H       // N
        {3,  9}, {2,  9}, {3,  7}, {0,  9},
        // P          // Q
        {0,  7}, {1,  7},
    },
    {
        // 4
        //{com, seg}
        // A          // B     // C     // D
        {3, 12}, {2, 12}, {1, 12}, {0,  12},
        // E          // F     // G     // M
        {1, 10}, {2, 10}, {2, 11}, {1,  13},
        // J          // K       // H       // N
        {3, 13}, {2, 13}, {3, 11}, {0, 13},
        // P       // Q
        {0, 11}, {1, 11},
    },
    {
        // 5
        //{com, seg}
        // A          // B     // C     // D
        {3, 16}, {2, 16}, {1, 16}, {0,  16},
        // E          // F     // G     // M
        {1, 14}, {2, 14}, {2, 15}, {1,  17},
        // J          // K     // H     // N
        {3, 17}, {2, 17}, {3, 15}, {0, 17},
        // P          // Q
        {0, 15}, {1, 15},
    },
    {
        // 6
        //{com, seg}
        // A          // B     // C     // D
        {3, 20}, {2, 20}, {1, 20}, {0,  20},
        // E          // F     // G     // M
        {1, 18}, {2, 18}, {2, 19}, {1,  21},
        // J          // K       // H       // N
        {3, 21}, {2, 21}, {3, 19}, {0, 21},
        // P          // Q
        {0, 19}, {1, 19},
    },
    {
        // 7
        //{com, seg}
        // A          // B     // C     // D
        {3, 24}, {2, 24}, {1, 24}, {0,  24},
        // E          // F     // G     // M
        {1, 22}, {2, 22}, {2, 23}, {1,  25},
        // J          // K       // H       // N
        {3, 25}, {2, 25}, {3, 23}, {0, 25},
        // P          // Q
        {0, 23}, {1, 23},
    },

};

void LCD_SetPixel(uint32_t u32Com, uint32_t u32Seg, uint32_t u32OnFlag)
{
    int32_t memnum = u32Seg / 4;
    int32_t seg_shift = 8*(u32Seg-(4*memnum));

    if(u32OnFlag) {
        if(memnum==0) {
            LCD->MEM_0 |= (1<<u32Com)<<seg_shift;
        } else if(memnum==1) {
            LCD->MEM_1 |= (1<<u32Com)<<seg_shift;
        } else if(memnum==2) {
            LCD->MEM_2 |= (1<<u32Com)<<seg_shift;
        } else if(memnum==3) {
            LCD->MEM_3 |= (1<<u32Com)<<seg_shift;
        } else if(memnum==4) {
            LCD->MEM_4 |= (1<<u32Com)<<seg_shift;
        } else if(memnum==5) {
            LCD->MEM_5 |= (1<<u32Com)<<seg_shift;
        } else if(memnum==6) {
            LCD->MEM_6 |= (1<<u32Com)<<seg_shift;
        } else if(memnum==7) {
            LCD->MEM_7 |= (1<<u32Com)<<seg_shift;
        } else if(memnum==8) {
            LCD->MEM_8 |= (1<<u32Com)<<seg_shift;
        } else if(memnum==9) {
            LCD->MEM_9 |= (1<<u32Com)<<seg_shift;
        }
    } else {
        if(memnum==0) {
            LCD->MEM_0 &= ~((1<<u32Com)<<seg_shift);
        } else if(memnum==1) {
            LCD->MEM_1 &= ~((1<<u32Com)<<seg_shift);
        } else if(memnum==2) {
            LCD->MEM_2 &= ~((1<<u32Com)<<seg_shift);
        } else if(memnum==3) {
            LCD->MEM_3 &= ~((1<<u32Com)<<seg_shift);
        } else if(memnum==4) {
            LCD->MEM_4 &= ~((1<<u32Com)<<seg_shift);
        } else if(memnum==5) {
            LCD->MEM_5 &= ~((1<<u32Com)<<seg_shift);
        } else if(memnum==6) {
            LCD->MEM_6 &= ~((1<<u32Com)<<seg_shift);
        } else if(memnum==7) {
            LCD->MEM_7 &= ~((1<<u32Com)<<seg_shift);
        } else if(memnum==8) {
            LCD->MEM_8 &= ~((1<<u32Com)<<seg_shift);
        } else if(memnum==9) {
            LCD->MEM_9 &= ~((1<<u32Com)<<seg_shift);
        }

    }
}
//// Nutiny_SDK_Nano130һ"8"eΡfΡgεߣֵǰһLCD_MEMȥ.
//// ʾһ8Ҫд ǰ LCD_EM
void Lcd_ShowNum(uint32_t adress, uint32_t Data)      // Ϊʾλ, ʾ
{
  uint8_t temp,Num,com,seg; 
	Num=Tab_Num[Data];
	for(temp=0;temp<8;temp++)
	{
		com=NumComSegTab[adress][temp][0];
		seg=NumComSegTab[adress][temp][1];
		if((Num&0x01)==1)			
			LCD_SetPixel(com,seg,1);
		else
			LCD_SetPixel(com,seg,0);
	  Num=Num>>1;
  }
      
}



int32_t FMC_Write(uint32_t u32addr, uint32_t u32data)
{
	FMC->ISPCMD = FMC_ISPCMD_PROGRAM;
  FMC->ISPADR	= u32addr;
	FMC->ISPDAT	= u32data;
	FMC->ISPTRG = FMC_ISPTRG_ISPGO;	
//	__ISB();
	while (FMC->ISPTRG & FMC_ISPTRG_ISPGO) ;
	

	if (FMC->ISPCON & FMC_ISPSTA_ISPFF)
	{
		FMC->ISPCON = FMC_ISPSTA_ISPFF;
		return 0;
	}
	
	return 1;
}

int32_t FMC_Erase(uint32_t u32addr)
{
	FMC->ISPCMD = FMC_ISPCMD_PAGE_ERASE;
  FMC->ISPADR	= u32addr;
	FMC->ISPTRG = FMC_ISPTRG_ISPGO;	
	
	while (FMC->ISPTRG & FMC_ISPTRG_ISPGO) ;

	if (FMC->ISPCON & FMC_ISPSTA_ISPFF)
	{
		FMC->ISPCON = FMC_ISPSTA_ISPFF;
		return 0;
	}
	
	return 1;
}

/**
  * @brief  Read a word from specified flash address. 
  * @param  u32addr: Flash word address. Must be a word aligned address.
  * @param  u32data: A 32-bit buffer to store the word read from flash. 
  * @retval E_FMC_OK: Success
  * @retval E_FMC_ISP_FAIL: ISP command failed.
  */
int32_t FMC_Read(uint32_t u32addr)
{ 
	FMC->ISPCMD = FMC_ISPCMD_READ;
  FMC->ISPADR	= u32addr;
	FMC->ISPTRG = FMC_ISPTRG_ISPGO;	
	
	while (FMC->ISPTRG & FMC_ISPTRG_ISPGO) ;

	if (FMC->ISPCON & FMC_ISPSTA_ISPFF)
	{
		FMC->ISPCON = FMC_ISPSTA_ISPFF;
		return 0;
	}
	
	return FMC->ISPDAT;
}
void DataFlashTest(void)
{	
	uint32_t Address ;
	
	UNLOCKREG();
	CLK->AHBCLK |= CLK_AHBCLK_ISP_EN;
	FMC->ISPCON |= FMC_ISPCON_ISPEN;
	
	Address = FMC->DFBADR;//ȡDataFlashַҪConfigʹDataFlashûַ
	FMC_Erase(Address) ;

	Address = FMC->DFBADR;
	FMC_Write(Address,0X12345678);
	if(FMC_Read(Address)!=0X12345678)
		while(1);
	
	Address += 4;
	FMC_Write(Address,0X11111111);
	if(FMC_Read(Address)!=0X11111111)
		while(1);
	
	Address += 4;
	FMC_Write(Address,0X22222222);
	if(FMC_Read(Address)!=0X22222222)
		while(1);
	
	Address += 4;;
	FMC_Write(Address,0X33333333);
	if(FMC_Read(Address)!=0X33333333)
		while(1);
}